@@ -5,62 +5,27 @@ use Exporter;
 use YAML::Syck ();
 
 BEGIN {
-    $VERSION   = '1.30_01';
-    @EXPORT_OK = qw( Load Dump LoadFile DumpFile DumpInto );
-    @ISA       = 'Exporter';
-    *Load      = \&YAML::Syck::LoadJSON;
-    *Dump      = \&YAML::Syck::DumpJSON;
+    $VERSION    = '0.27';
+    @EXPORT_OK  = qw( Load Dump LoadFile DumpFile );
+    @ISA        = 'Exporter';
+    *Load       = \&YAML::Syck::LoadJSON;
+    *Dump       = \&YAML::Syck::DumpJSON;
 }
 
 sub DumpFile {
     my $file = shift;
-    if ( YAML::Syck::_is_glob($file) ) {
-        my $err = YAML::Syck::DumpJSONFile( $_[0], $file );
-        if ($err) {
-            $! = 0 + $err;
-            die "Error writing to filehandle $file: $!\n";
-        }
+    if ( YAML::Syck::_is_openhandle($file) ) {
+        print {$file} YAML::Syck::DumpJSON($_[0]);
     }
     else {
-        open( my $fh, '>', $file ) or die "Cannot write to $file: $!";
-        my $err = YAML::Syck::DumpJSONFile( $_[0], $fh );
-        if ($err) {
-            $! = 0 + $err;
-            die "Error writing to file $file: $!\n";
-        }
-        close $fh
-          or die "Error writing to file $file: $!\n";
+        local *FH;
+        open FH, "> $file" or die "Cannot write to $file: $!";
+        print FH YAML::Syck::DumpJSON($_[0]);
+        close FH;
     }
-    return 1;
-}
-
-sub LoadFile {
-    my $file = shift;
-    if ( YAML::Syck::_is_glob($file) ) {
-        YAML::Syck::LoadJSON(
-            do { local $/; <$file> }
-        );
-    }
-    else {
-        if ( !-e $file || -z $file ) {
-            die("'$file' is non-existent or empty");
-        }
-        open( my $fh, '<', $file ) or die "Cannot read from $file: $!";
-        YAML::Syck::LoadJSON(
-            do { local $/; <$fh> }
-        );
-    }
-}
-
-sub DumpInto {
-    my $bufref = shift;
-    ( ref $bufref ) or die "DumpInto not given reference to output buffer\n";
-    YAML::Syck::DumpJSONInto( $_[0], $bufref );
-    1;
 }
 
 $JSON::Syck::ImplicitTyping  = 1;
-$JSON::Syck::MaxDepth        = 512;
 $JSON::Syck::Headless        = 1;
 $JSON::Syck::ImplicitUnicode = 0;
 $JSON::Syck::SingleQuote     = 0;
@@ -71,7 +36,7 @@ __END__
 
 =head1 NAME
 
-JSON::Syck - JSON is YAML (but consider using L<JSON::XS> instead!)
+JSON::Syck - JSON is YAML (but consider using JSON::XS instead!)
 
 =head1 SYNOPSIS
 
@@ -84,10 +49,6 @@ JSON::Syck - JSON is YAML (but consider using L<JSON::XS> instead!)
     my $data = JSON::Syck::LoadFile($file);
     JSON::Syck::DumpFile($file, $data);
 
-    # Dump into a pre-existing buffer
-    my $json;
-    JSON::Syck::DumpInto(\$json, $data);
-
 =head1 DESCRIPTION
 
 JSON::Syck is a syck implementation of JSON parsing and generation. Because
@@ -122,7 +83,7 @@ dereferences to get the actual scalar value.
 
 JSON::Syck raises an exception when you pass in circular references.
 
-If you want to serialize self referencing stuff, you should use
+If you want to serialize self refernecing stuff, you should use
 YAML which supports it.
 
 =head2 SUBROUTINE REFERENCE
@@ -143,13 +104,6 @@ as in:
   Perl (UTF-8 bytes)   => JSON (UTF-8 flagged)
   Perl (UTF-8 flagged) => JSON (UTF-8 flagged)
 
-By default, JSON::Syck::Dump will only transverse up to 512 levels of
-a datastructure in order to avoid an infinite loop when it is
-presented with an circular reference.
-
-However, you set C<$JSON::Syck::MaxLevels> to a larger value if you
-have very complex structures.
-
 Unfortunately, there's no implicit way to dump Perl UTF-8 flagged data
 structure to utf-8 encoded JSON. To do this, simply use Encode module, e.g.:
 
@@ -176,17 +130,9 @@ convenient to use single quotes.
 Set C<$JSON::Syck::SingleQuote> to 1 will make both C<Dump> and C<Load> expect
 single-quoted string literals.
 
-=head1 BUGS
-
-Dumping into tied (or other magic variables) with C<DumpInto> might not work
-properly in all cases.
-
-When dumping with C<DumpFile>, some spacing might be wrong and
-C<$JSON::Syck::SingleQuote> might be handled incorrectly.
-
 =head1 SEE ALSO
 
-L<JSON::XS>, L<YAML::Syck>
+L<JSON::XS>,
 
 =head1 AUTHORS
 
@@ -196,7 +142,7 @@ Tatsuhiko Miyagawa E<lt>miyagawa@gmail.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2005-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2005, 2006, 2007, 2008 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This software is released under the MIT license cited below.
 
