@@ -1,31 +1,28 @@
 package YAML::Syck;
-
 # See documentation after the __END__ mark.
 
 use strict;
 use vars qw(
-  @ISA @EXPORT @EXPORT_OK $VERSION
-  $Headless $SortKeys $SingleQuote
-  $ImplicitBinary $ImplicitTyping $ImplicitUnicode
-  $UseCode $LoadCode $DumpCode
-  $DeparseObject $LoadBlessed
+    @ISA @EXPORT $VERSION
+    $Headless $SortKeys $SingleQuote
+    $ImplicitTyping $ImplicitUnicode 
+    $UseCode $LoadCode $DumpCode
+    $DeparseObject
 );
-use 5.006;
+use 5.00307;
 use Exporter;
 
 BEGIN {
-    $VERSION   = '1.30_01';
-    @EXPORT    = qw( Dump Load DumpFile LoadFile );
-    @EXPORT_OK = qw( DumpInto );
-    @ISA       = qw( Exporter );
+    $VERSION = '1.01';
+    @EXPORT  = qw( Dump Load DumpFile LoadFile );
+    @ISA     = qw( Exporter );
 
-    $SortKeys    = 1;
-    $LoadBlessed = 1;
+    $SortKeys = 1;
 
     local $@;
     eval {
         require XSLoader;
-        XSLoader::load( __PACKAGE__, $VERSION );
+        XSLoader::load(__PACKAGE__, $VERSION);
         1;
     } or do {
         require DynaLoader;
@@ -36,26 +33,26 @@ BEGIN {
 }
 
 use constant QR_MAP => {
-    ''   => sub { qr{$_[0]} },
-    x    => sub { qr{$_[0]}x },
-    i    => sub { qr{$_[0]}i },
-    s    => sub { qr{$_[0]}s },
-    m    => sub { qr{$_[0]}m },
-    ix   => sub { qr{$_[0]}ix },
-    sx   => sub { qr{$_[0]}sx },
-    mx   => sub { qr{$_[0]}mx },
-    si   => sub { qr{$_[0]}si },
-    mi   => sub { qr{$_[0]}mi },
-    ms   => sub { qr{$_[0]}sm },
-    six  => sub { qr{$_[0]}six },
-    mix  => sub { qr{$_[0]}mix },
-    msx  => sub { qr{$_[0]}msx },
-    msi  => sub { qr{$_[0]}msi },
-    msix => sub { qr{$_[0]}msix },
+    ''   => sub { qr{$_[0]}     }, 
+    x    => sub { qr{$_[0]}x    }, 
+    i    => sub { qr{$_[0]}i    }, 
+    s    => sub { qr{$_[0]}s    }, 
+    m    => sub { qr{$_[0]}m    }, 
+    ix   => sub { qr{$_[0]}ix   }, 
+    sx   => sub { qr{$_[0]}sx   }, 
+    mx   => sub { qr{$_[0]}mx   }, 
+    si   => sub { qr{$_[0]}si   }, 
+    mi   => sub { qr{$_[0]}mi   }, 
+    ms   => sub { qr{$_[0]}sm   }, 
+    six  => sub { qr{$_[0]}six  }, 
+    mix  => sub { qr{$_[0]}mix  }, 
+    msx  => sub { qr{$_[0]}msx  }, 
+    msi  => sub { qr{$_[0]}msi  }, 
+    msix => sub { qr{$_[0]}msix }, 
 };
 
 sub __qr_helper {
-    if ( $_[0] =~ /\A  \(\?  ([ixsm]*)  (?:-  (?:[ixsm]*))?  : (.*) \)  \z/x ) {
+    if ($_[0] =~ /\A  \(\?  ([ixsm]*)  (?:-  (?:[ixsm]*))?  : (.*) \)  \z/x) {
         my $sub = QR_MAP()->{$1} || QR_MAP()->{''};
         &$sub($2);
     }
@@ -65,83 +62,72 @@ sub __qr_helper {
 }
 
 sub Dump {
-    $#_
-      ? join( '', map { YAML::Syck::DumpYAML($_) } @_ )
-      : YAML::Syck::DumpYAML( $_[0] );
+    $#_ ? join('', map { YAML::Syck::DumpYAML($_) } @_)
+        : YAML::Syck::DumpYAML($_[0]);
 }
 
 sub Load {
     if (wantarray) {
-        my ($rv) = YAML::Syck::LoadYAML( $_[0] );
+        my ($rv) = YAML::Syck::LoadYAML($_[0]);
         @{$rv};
     }
     else {
-        @_ = $_[0];
-        goto &YAML::Syck::LoadYAML;
+        YAML::Syck::LoadYAML($_[0]);
     }
 }
 
-sub _is_glob {
+# NOTE. The code below (_is_openhandle) avoids to require/load
+# Scalar::Util unless it is given a ref or glob
+# as an argument. That is purposeful, so to avoid
+# the need for this dependency unless strictly necessary.
+# If that was not the case, Scalar::Util::openhandle could
+# be used directly.
+
+sub _is_openhandle {
     my $h = shift;
-
-    return 1 if ( ref($h) eq 'GLOB' );
-    return 1 if ( ref( \$h ) eq 'GLOB' );
-    return 1 if ( ref($h) =~ m/^IO::/ );
-
-    return;
+    if ( ref($h) || ref(\$h) eq 'GLOB' ) {
+        require Scalar::Util;
+        return Scalar::Util::openhandle($h);
+    } else {
+        return undef;
+    }
 }
 
 sub DumpFile {
     my $file = shift;
-    if ( _is_glob($file) ) {
-        for (@_) {
-            my $err = YAML::Syck::DumpYAMLFile( $_, $file );
-            if ($err) {
-                $! = 0 + $err;
-                die "Error writing to filehandle $file: $!\n";
-            }
+    if ( _is_openhandle($file) ) {
+        if ($#_) {
+            print {$file} YAML::Syck::DumpYAML($_) for @_;
+        }
+        else {
+            print {$file} YAML::Syck::DumpYAML($_[0]);
         }
     }
     else {
-        open( my $fh, '>', $file ) or die "Cannot write to $file: $!";
-        for (@_) {
-            my $err = YAML::Syck::DumpYAMLFile( $_, $fh );
-            if ($err) {
-                $! = 0 + $err;
-                die "Error writing to file $file: $!\n";
-            }
+        local *FH;
+        open FH, "> $file" or die "Cannot write to $file: $!";
+        if ($#_) {
+            print FH YAML::Syck::DumpYAML($_) for @_;
         }
-        close $fh
-          or die "Error writing to file $file: $!\n";
+        else {
+            print FH YAML::Syck::DumpYAML($_[0]);
+        }
+        close FH;
     }
-    return 1;
 }
 
 sub LoadFile {
     my $file = shift;
-    if ( _is_glob($file) ) {
-        Load(
-            do { local $/; <$file> }
-        );
+    if ( _is_openhandle($file) ) {
+        Load(do { local $/; <$file> });
     }
     else {
-        if ( !-e $file || -z $file ) {
-            die("'$file' is empty or non-existent");
-        }
-        open( my $fh, '<', $file ) or die "Cannot read from $file: $!";
-        Load(
-            do { local $/; <$fh> }
-        );
+        local *FH;
+        open FH, "< $file" or die "Cannot read from $file: $!";
+        Load(do { local $/; <FH> });
     }
 }
 
-sub DumpInto {
-    my $bufref = shift;
-    ( ref $bufref ) or die "DumpInto not given reference to output buffer\n";
-    YAML::Syck::DumpYAMLInto( $_, $bufref ) for @_;
-    1;
-}
-
 1;
 
 __END__
@@ -151,6 +137,10 @@ __END__
 
 YAML::Syck - Fast, lightweight YAML loader and dumper
 
+=head1 VERSION
+
+This document describes version 1.01 of YAML::Syck, released January 18, 2008.
+
 =head1 SYNOPSIS
 
     use YAML::Syck;
@@ -170,10 +160,6 @@ YAML::Syck - Fast, lightweight YAML loader and dumper
     $yaml = Dump(@data);
     @data = Load($yaml);
 
-    # Dumping into a pre-existing output buffer
-    my $yaml;
-    DumpInto(\$yaml, @data);
-
 =head1 DESCRIPTION
 
 This module provides a Perl interface to the B<libsyck> data serialization
@@ -185,13 +171,6 @@ B<NOTE>: If you are working with other language's YAML/Syck bindings
 calling the C<Load>/C<Dump> functions.  The default setting is for
 preserving backward-compatibility with C<YAML.pm>.
 
-=head1 Differences Between YAML::Syck and YAML
-
-=head2 Error handling
-
-Some calls are designed to die rather than returning YAML. You should wrap
-your calls in eval to assure you do not get unexpected results.
-
 =head1 FLAGS
 
 =head2 $YAML::Syck::Headless
@@ -228,12 +207,6 @@ byte strings with high-bit set will be dumped with backslash escaping.
 However, because YAML does not distinguish between these two kinds of strings,
 so this flag will affect loading of both variants of strings.
 
-If you want to use LoadFile or DumpFile with unicode, you are required to open
-your own file in order to assure it's UTF8 encoded:
-
-  open(my $fh, ">:encoding(UTF-8)", "out.yml");
-  DumpFile($fh, $hashref);
-
 =head2 $YAML::Syck::ImplicitBinary
 
 Defaults to false.  For Perl 5.8.0 or later, setting this to a true value will
@@ -248,23 +221,9 @@ each of them defaults to false.
 Setting C<$YAML::Syck::UseCode> to a true value is equivalent to setting
 both C<$YAML::Syck::LoadCode> and C<$YAML::Syck::DumpCode> to true.
 
-=head2 $YAML::Syck::LoadBlessed
-
-Defaults to true. Setting to false will block YAML::Syck from doing ANY
-blessing. This is an interface change since 1.21. The variable name was
-misleading, implying that no blessing would happen when in fact it did.
-
-Prior to 1.22, setting this to a false value only prevented C<Load> from
-blessing tag names that did not begin with C<!!perl> or C<!perl>;.
-
 =head1 BUGS
 
-Dumping Glob/IO values do not work yet.
-
-Dumping of Tied variables is unsupported.
-
-Dumping into tied (or other magic variables) with C<DumpInto> might not work
-properly in all cases.
+Dumping Glob/IO values does not work yet.
 
 =head1 CAVEATS
 
@@ -278,22 +237,7 @@ Tag names such as C<!!perl/hash:Foo> is blessed into the package C<Foo>, but
 the C<!hs/foo> and C<!!hs/Foo> tags are blessed into C<hs::Foo>.  Note that
 this holds true even if the tag contains non-word characters; for example,
 C<!haskell.org/Foo> is blessed into C<haskell.org::Foo>.  Please use
-L<Class::Rebless> to cast it into other user-defined packages. You can also
-set the LoadBlessed flag false to disable all blessing.
-
-This module has L<a lot of known
-issues|https://rt.cpan.org/Public/Dist/Display.html?Name=YAML-Syck>
-and has only been semi-actively maintained since 2007. If you
-encounter an issue with it probably won't be fixed unless you L<offer
-up a patch|http://github.com/toddr/YAML-Syck> in Git that's ready for
-release.
-
-There are still good reasons to use this module, such as better
-interoperability with other syck wrappers (like Ruby's), or some edge
-case of YAML's syntax that it handles better. It'll probably work
-perfectly for you, but if it doesn't you may want to look at
-L<YAML::XS>, or perhaps at looking another serialization format like
-L<JSON>.
+L<Class::Rebless> to cast it into other user-defined packages.
 
 =head1 SEE ALSO
 
@@ -307,7 +251,7 @@ Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2005-2009 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2005, 2006, 2007, 2008 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This software is released under the MIT license cited below.
 
