@@ -753,6 +753,17 @@ yaml_syck_emitter_handler
             case SVt_PVHV: { strcat(tag, "hash:");   break; }
             case SVt_PVCV: { strcat(tag, "code:");   break; }
             case SVt_PVGV: { strcat(tag, "glob:");   break; }
+#if PERL_VERSION > 10
+            case SVt_REGEXP: {
+                if (strEQ(ref, "Regexp")) {
+                    strcat(tag, "regexp");
+                    ref += 6; /* empty string */
+                } else {
+                    strcat(tag, "regexp:");
+                }
+                break;
+            }
+#endif
 
             /* flatten scalar ref objects so that they dump as !perl/scalar:Foo::Bar foo */
             case SVt_PVMG: {
@@ -760,6 +771,14 @@ yaml_syck_emitter_handler
                     strcat(tag, "ref:");
                     break;
                 }
+#if PERL_VERSION > 10
+                else {
+                    strcat(tag, "scalar:");
+                    sv = SvRV(sv);
+                    ty = SvTYPE(sv);
+                    break;
+                }
+#else
                 else {
                     MAGIC *mg;
                     if ( (mg = mg_find(SvRV(sv), PERL_MAGIC_qr) ) ) {
@@ -780,6 +799,7 @@ yaml_syck_emitter_handler
                     }
                     break;
                 }
+#endif
             }
         }
         strcat(tag, ref);
@@ -801,6 +821,14 @@ yaml_syck_emitter_handler
                 e->indent = PERL_SYCK_INDENT_LEVEL;
                 break;
             }
+#if PERL_VERSION > 10
+            case SVt_REGEXP: {
+                STRLEN len = sv_len(sv);
+                syck_emit_scalar( e, OBJOF("tag:!perl:regexp"), SCALAR_STRING, 0, 0, 0, SvPV_nolen(sv), len );
+                syck_emit_end(e);
+                break;
+            }
+#endif
             default: {
                 syck_emit_map(e, OBJOF("tag:!perl:ref"), MAP_NONE);
                 *tag = '\0';
